@@ -184,6 +184,11 @@ def _process_drivers_and_hardware_types(conf, env):
     if 'snmp' in enabled_hardware_types:
         power_interfaces.add('snmp')
 
+    deploy_interfaces = {'iscsi', 'direct', 'ansible'}
+    if 'fake-hardware' in enabled_hardware_types:
+        deploy_interfaces.add('fake')
+        boot_interfaces.add('fake')
+
     env['IronicEnabledHardwareTypes'] = sorted(enabled_hardware_types)
 
     env['IronicEnabledBiosInterfaces'] = sorted(bios_interfaces)
@@ -193,6 +198,7 @@ def _process_drivers_and_hardware_types(conf, env):
     env['IronicEnabledPowerInterfaces'] = sorted(power_interfaces)
     env['IronicEnabledRaidInterfaces'] = sorted(raid_interfaces)
     env['IronicEnabledVendorInterfaces'] = sorted(vendor_interfaces)
+    env['IronicEnabledDeployInterfaces'] = sorted(deploy_interfaces)
 
 
 def _process_ipa_args(conf, env):
@@ -218,7 +224,18 @@ def _generate_inspection_subnets():
         env_dict = {}
         s = CONF.get(subnet)
         env_dict['tag'] = subnet
-        env_dict['ip_range'] = s.inspection_iprange
+        if netaddr.IPNetwork(s.cidr).version == 4:
+            env_dict['ip_range'] = s.inspection_iprange
+        if netaddr.IPNetwork(s.cidr).version == 6:
+            if CONF['ipv6_address_mode'] == 'dhcpv6-stateful':
+                env_dict['ip_range'] = s.inspection_iprange
+            if CONF['ipv6_address_mode'] == 'dhcpv6-stateless':
+                # dnsmasq(8): A static-only subnet with address all zeros may
+                # be used as a "catch-all" address to enable replies to all
+                # Information-request packets on a subnet which is provided
+                # with stateless DHCPv6, ie --dhcp-range=::,static
+                env_dict['ip_range'] = ','.join(
+                    [str(netaddr.IPNetwork(s.cidr).ip), 'static'])
         env_dict['netmask'] = str(netaddr.IPNetwork(s.cidr).netmask)
         env_dict['gateway'] = s.gateway
         env_dict['host_routes'] = s.host_routes
@@ -383,6 +400,9 @@ def prepare_undercloud_deploy(upgrade=False, no_validations=True,
                               inflight=False):
     """Prepare Undercloud deploy command based on undercloud.conf"""
 
+    if CONF.get('undercloud_hostname'):
+        utils.set_hostname(CONF.get('undercloud_hostname'))
+
     env_data = {}
     registry_overwrites = {}
     deploy_args = []
@@ -446,14 +466,20 @@ def prepare_undercloud_deploy(upgrade=False, no_validations=True,
         env_data['NeutronDnsDomain'] = CONF['overcloud_domain_name']
         deploy_args.append('--local-domain=%s' % CONF['overcloud_domain_name'])
 
+    local_registry_name = '.'.join([utils.get_short_hostname(),
+                                    'ctlplane',
+                                    CONF['overcloud_domain_name']])
     if CONF.get('container_cli', 'podman') == 'podman':
-        env_data['DockerInsecureRegistryAddress'] = [
-            CONF['local_ip'].split('/')[0]]
+        env_data['DockerInsecureRegistryAddress'] = [local_registry_name]
+        env_data['DockerInsecureRegistryAddress'].append(
+            CONF['local_ip'].split('/')[0])
         env_data['DockerInsecureRegistryAddress'].append(
             CONF['undercloud_admin_host'])
     else:
         env_data['DockerInsecureRegistryAddress'] = [
-            '%s:8787' % CONF['local_ip'].split('/')[0]]
+            '%s:8787' % local_registry_name]
+        env_data['DockerInsecureRegistryAddress'].append(
+            '%s:8787' % CONF['local_ip'].split('/')[0])
         env_data['DockerInsecureRegistryAddress'].append(
             '%s:8787' % CONF['undercloud_admin_host'])
     env_data['DockerInsecureRegistryAddress'].extend(
@@ -469,7 +495,7 @@ def prepare_undercloud_deploy(upgrade=False, no_validations=True,
         env_data['DockerRegistryMirror'] = CONF['container_registry_mirror']
 
     # This parameter the IP address used to bind the local container registry
-    env_data['LocalContainerRegistry'] = CONF['local_ip'].split('/')[0]
+    env_data['LocalContainerRegistry'] = local_registry_name
 
     if CONF['additional_architectures']:
         # In queens (instack-undercloud) we used this to setup additional
@@ -750,9 +776,6 @@ def prepare_undercloud_deploy(upgrade=False, no_validations=True,
 
         deploy_args += ['--hieradata-override=%s' % data_file]
 
-    if CONF.get('undercloud_hostname'):
-        utils.set_hostname(CONF.get('undercloud_hostname'))
-
     if CONF.get('enable_validations') and not no_validations:
         utils.ansible_symlink()
         undercloud_preflight.check(verbose_level, upgrade)
